@@ -1,3 +1,5 @@
+#include "antprojectpart.h"
+
 #include <qapplication.h>
 #include <qfile.h>
 #include <qfileinfo.h>
@@ -30,7 +32,6 @@
 #include "classpathwidget.h"
 
 
-#include "antprojectpart.h"
 
 
 typedef KDevGenericFactory<AntProjectPart> AntProjectFactory;
@@ -96,21 +97,21 @@ void AntProjectPart::openProject(const QString &dirName, const QString &projectN
 
   fillMenu();
 
-  QFile f(dirName + "/" + projectName + ".filelist");
-  if (f.open(IO_ReadOnly)) 
+  QFile f(dirName + "/" + projectName.lower() + ".kdevelop" + ".filelist");
+  if (f.open(IO_ReadOnly))
   {
     QTextStream stream(&f);
-    while (!stream.atEnd()) 
+    while (!stream.atEnd())
     {
       QString s = stream.readLine();
       if (!s.startsWith("#"))
         m_sourceFiles << s;
     }
-  } 
-  else 
+  }
+  else
     populateProject();
-  
-  KDevProject::openProject( dirName, projectName );  
+
+  KDevProject::openProject( dirName, projectName );
 }
 
 
@@ -123,30 +124,30 @@ void AntProjectPart::populateProject()
   s.push(m_projectDirectory);
 
   QDir dir;
-  do 
+  do
   {
     dir.setPath(s.pop());
     kdDebug() << "Examining: " << dir.path() << endl;
     const QFileInfoList *dirEntries = dir.entryInfoList();
     QPtrListIterator<QFileInfo> it(*dirEntries);
-    for (; it.current(); ++it) 
+    for (; it.current(); ++it)
     {
       QString fileName = it.current()->fileName();
       if (fileName == "." || fileName == "..")
         continue;
       QString path = it.current()->absFilePath();
-      if (it.current()->isDir()) 
+      if (it.current()->isDir())
       {
         kdDebug() << "Pushing: " << path << endl;
         s.push(path);
       }
-      else 
+      else
       {
         kdDebug() << "Adding: " << path << endl;
         m_sourceFiles.append(path.mid(prefixlen));
       }
     }
-  } 
+  }
   while (!s.isEmpty());
 
   QApplication::restoreOverrideCursor();
@@ -162,8 +163,8 @@ void AntProjectPart::closeProject()
   m_targetMenu->clear();
 
   m_antOptions = AntOptions();
-  
-  QFile f(m_projectDirectory + "/" + m_projectName + ".filelist");
+
+  QFile f(m_projectDirectory + "/" + m_projectName.lower() + ".kdevelop" + ".filelist");
   if (!f.open(IO_WriteOnly))
     return;
 
@@ -246,34 +247,34 @@ QString AntProjectPart::runDirectory() const
   *   if run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString AntProjectPart::mainProgram(bool relative) const
+QString AntProjectPart::mainProgram() const
 {
-	return QString::null;
+    QDomDocument * dom = projectDom();
 
-    /// \FIXME put the code below into use!
-    QDomDocument &dom = *projectDom();
+    if ( !dom ) return QString();
 
-    /// \FIXME there is no kdevantproject so this will not work !
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevantproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevantproject/run/mainprogram");
+    QString DomMainProgram = DomUtil::readEntry( *dom, "/kdevantproject/run/mainprogram");
 
-    if ( directoryRadioString == "custom" )
-        return DomMainProgram;
+    if ( DomMainProgram.isEmpty() ) return QString();
 
-    if ( relative == false )
-        return buildDirectory() + "/" + DomMainProgram;
-
-    if ( directoryRadioString == "executable" ) {
-        int pos = DomMainProgram.findRev('/');
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
-        return DomMainProgram;
+    if ( DomMainProgram.startsWith("/") )   // assume absolute path
+    {
+        return DomMainProgram;    
     }
-    else
-        return DomMainProgram;
+    else // assume project relative path
+    {
+        return projectDirectory() + "/" + DomMainProgram;
+    }
+
+    return QString();
 }
 
 
+QString AntProjectPart::debugArguments() const
+{
+    return QString("");
+}
+
 /** Retuns a QString with the run command line arguments */
 QString AntProjectPart::runArguments() const
 {
@@ -285,7 +286,7 @@ QString AntProjectPart::runArguments() const
 QString AntProjectPart::activeDirectory() const
 {
   /// \FIXME
-  
+
 //  return m_projectDirectory;
 
 	// returning m_projectDirectory is wrong, the path returned should be _relative_ to the project dir
@@ -299,10 +300,10 @@ QStringList AntProjectPart::allFiles() const
 /* QStringList res;
 
   QStringList::ConstIterator it;
-  for (it = m_sourceFiles.begin(); it != m_sourceFiles.end(); ++it) 
+  for (it = m_sourceFiles.begin(); it != m_sourceFiles.end(); ++it)
   {
     QString fileName = *it;
-    if (!fileName.startsWith("/")) 
+    if (!fileName.startsWith("/"))
     {
       fileName.prepend("/");
       fileName.prepend(m_projectDirectory);
@@ -311,7 +312,7 @@ QStringList AntProjectPart::allFiles() const
   }
 
   return res;*/
-  
+
 	// return all files relative to the project directory!
 	return m_sourceFiles;
 }
@@ -321,19 +322,19 @@ void AntProjectPart::addFile(const QString &fileName)
 {
 	QStringList fileList;
 	fileList.append ( fileName );
-	
+
 	this->addFiles ( fileList );
 }
 
 void AntProjectPart::addFiles ( const QStringList& fileList )
 {
-	QStringList::ConstIterator it;	
-	
+	QStringList::ConstIterator it;
+
 	for ( it = fileList.begin(); it != fileList.end(); ++it )
 	{
 		m_sourceFiles.append (*it );
 	}
-	
+
 	kdDebug() << "Emitting addedFilesToProject" << endl;
 	emit addedFilesToProject(fileList);
 }
@@ -342,7 +343,7 @@ void AntProjectPart::removeFile(const QString &fileName)
 {
 	QStringList fileList;
 	fileList.append ( fileName );
-	
+
 	this->removeFiles ( fileList );
 }
 
@@ -456,7 +457,7 @@ void AntProjectPart::ant(const QString &target)
   QString cp;
   if (!m_classPath.count() == 0)
     cp = "CLASSPATH="+m_classPath.join(":");
-  
+
   makeFrontend()->queueCommand(m_projectDirectory, cmd.arg(cp).arg(m_projectDirectory).arg(target).arg(m_antOptions.m_buildXML).arg(verb).arg(options));
 }
 
@@ -576,7 +577,7 @@ void AntProjectPart::contextMenu(QPopupMenu *popup, const Context *context)
 
 void AntProjectPart::slotAddToProject()
 {
-	QStringList fileList;	
+	QStringList fileList;
 	fileList.append ( m_contextFileName );
 	addFiles ( fileList );
 }
@@ -584,7 +585,7 @@ void AntProjectPart::slotAddToProject()
 
 void AntProjectPart::slotRemoveFromProject()
 {
-	QStringList fileList;	
+	QStringList fileList;
 	fileList.append ( m_contextFileName );
 	removeFiles ( fileList );
 }
